' "Smart" front end to Beyond Compare v2

option explicit

Function OnInit(ByRef initData) ' OnInit is called by DOpus to initialize the script
   
   initData.name = "Smart Beyond Compare V2"
   initData.desc = "Adds the $BC command to Directory Opus"
   initData.copyright = "(c) 2014 AussieBoykie"
   initData.default_enable = true
   
   dim cmd : set cmd = initData.AddCommand()
   cmd.name = "$BC" ' This is the command name
   cmd.method = "Main" ' This is the routine to execute when the $BC command is invoked 
   cmd.desc = initData.desc
   cmd.label = initdata.name
   cmd.template = ""
   
End Function

Function Main(ByRef scriptCmdData) ' This is where the "smarts" are
   
   ' Define some key variables here
   
   Dim dlg ' DOpus dialog object
   Dim cdf ' DOpus scriptCmdData.func object
   Dim fsu ' DOpus fsutil object
   Dim dbg ' Switch used to control debug tracing
   
   ' Initialise key variables
   
   Set dlg = DOpus.Dlg ' DOpus dialog object
   Set fsu = DOpus.fsutil ' DOpus fsutil object
   Set cdf = scriptCmdData.func ' DOpus scriptCmdData.func object
   
   ' *** For testing purposes, use a lister level variable to activate debug trace
   dbg = cdf.command.IsSet("$lst:dbg")
   
   ' *** To unilaterally activate debug trace, uncomment the following statement   
   ' dbg = True
   
   If dbg Then DOpus.output "$BC Starting"   
   
   ' *** Define where to find BCompare.exe on your system
   ' *** Edit the following BC = "XXX" statement as appropriate
   
   Dim BC : BC = "C:\Utilities\BC3\BCompare.exe" ' Define where BCompare is
   
   ' *** The next statement is used to enable testing of Beyond Compare Beta
   ' *** This is specific to AussieBoykie's configuration
   ' *** It should have no effect on your system and can be commented out
   ' *** (by inserting a single quote in front of the statement)
   
   If cdf.Command.IsSet("$glob:BCBeta") Then BC = Replace(BC, "BC3", "BC4")
      
   Dim l, r : l = "" : r = "" ' Place holders for Left and Right comparands files   
   Dim lp, rp : lp = "" : rp = "" ' Place holders for Left and Right comparands paths
   
   cdf.command.deselect = false
   Dim nodest : nodest = cdf.desttab = 0
   If cdf.sourcetab.selected_files.count = 2 Then
      l = fsu.resolve(cdf.sourcetab.selected_files(0)) ' Two files selected in SOURCE
      r = fsu.resolve(cdf.sourcetab.selected_files(1))
      lp = cdf.sourcetab.path
      rp = lp
   ElseIf cdf.sourcetab.selected_dirs.count = 2 Then
      l = fsu.resolve(cdf.sourcetab.selected_dirs(0)) ' Two folders selected in SOURCE
      r = fsu.resolve(cdf.sourcetab.selected_dirs(1))
      lp = cdf.sourcetab.path
      rp = lp
   ElseIf NOT nodest Then
      If cdf.sourcetab.selected_files.count = 1 And cdf.desttab.selected_files.count = 1 Then
         l = fsu.resolve(cdf.sourcetab.selected_files(0)) ' One file selected in SOURCE, one in DEST
         r = fsu.resolve(cdf.desttab.selected_files(0))
         lp = cdf.sourcetab.path
         rp = cdf.desttab.path
      ElseIf cdf.sourcetab.selected_dirs.count = 1 And cdf.desttab.selected_dirs.count = 1 Then
         l = fsu.resolve(cdf.sourcetab.selected_dirs(0)) ' One folder selected in SOURCE, one in DEST
         r = fsu.resolve(cdf.desttab.selected_dirs(0))
         lp = cdf.sourcetab.path
         rp = cdf.desttab.path
      Else
         lp = cdf.sourcetab.path ' SOURCE and DEST folders will be compared
         rp = cdf.desttab.path
      End If
   Else
      lp = cdf.sourcetab.path ' No files/folders to compare
   End If
   
   Dim cmdline : cmdline = """" & BC & """" ' Basic BC command with no arguments
   If rp = "" Then ' No further arguments required
   ElseIf l = "" Then ' Compare folders
      cmdline = cmdline & " " & """" & lp & """"
      cmdline = cmdline & " " & """" & rp & """"
   Else ' Compare files
      cmdline = cmdline & " " & """" & l & """"
      cmdline = cmdline & " " & """" & r & """"
   End If
   
   If dbg Then
      DOpus.output "l = " & l
      DOpus.output "lp = " & lp
      DOpus.output "r = " & r
      DOpus.output "rp = " & rp
      DOpus.output Replace(cmdline, "%", "%%")
   End If
   
   ' *** The REPLACE function in the following statement appears to be needed
   ' *** to prevent the possibility of (e.g.) %1, %2, etc. being misinterpreted
   
   cdf.command.runcommand Replace(cmdline, "%", "%%") ' Execute Beyond Compare with appropriate args 
   
   If dbg Then DOpus.output "$BC: Ending"
   
End Function